@@ -148,9 +148,13 @@
   simple compatibility translations. Split part of <read_config> into
   <process_config_line>, in preparation for NIS support.
 
-    Last updated by Richard Gooch   26-APR-2000: Added NIS configuration
+    Updated by      Richard Gooch   26-APR-2000: Added NIS configuration
   support.
 
+    Last updated by Richard Gooch   27-APR-2000: Fixed DIR leak. Generate
+  synthetic REGISTER events on SIGHUP. Silently ignore NIS attempts when no
+  NIS domain set.
+
 
 */
 #include <unistd.h>
@@ -191,7 +195,7 @@
 #endif
 
 
-#define DEVFSD_VERSION "1.3.6"
+#define DEVFSD_VERSION "1.3.7"
 #define CONFIG_FILE "/etc/devfsd.conf"
 #define MAX_ARGS (6 + 1)
 
@@ -512,6 +516,7 @@ int main (int argc, char **argv)
 	do_servicing (fd, event_mask);
 	free_config ();
 	read_config (CONFIG_FILE, FALSE, &event_mask);
+	do_scan_and_service (opendir (mount_point), mount_point);
     }
 }   /*  End Function main  */
 
@@ -543,10 +548,14 @@ static void read_config (CONST char *location, flag optional,
     {
 	/*  It's a YP map  */
 	struct ypall_callback ypall_cbk;
+	char *domainname = NULL;
 
+	/*  If no domain: fail silently (probably too early)  */
+	if (yp_get_default_domain (&domainname) != 0) return;
+	if (domainname == NULL) return;
 	ypall_cbk.foreach = ( int (*) () ) process_yp_line;
 	ypall_cbk.data = (char *) event_mask;
-	if (yp_all (NULL, (char *) location + 1, &ypall_cbk) == 0)
+	if (yp_all (domainname, (char *) location + 1, &ypall_cbk) == 0)
 	{
 	    if (syslog_is_open)
 		SYSLOG (LOG_INFO, "read map: \"%s\"\n", location + 1);
@@ -1890,7 +1899,7 @@ static void do_open_syslog ()
 
 static void do_scan_and_service (DIR *dp, CONST char *dirname)
 /*  [SUMMARY] Scan a directory tree and generate register events on leaf nodes.
-    <dp> The directory pointer.
+    <dp> The directory pointer. This is closed upon completion.
     <dirname> The name of the directory.
     [RETURNS] Nothing.
 */
@@ -1928,6 +1937,7 @@ static void do_scan_and_service (DIR *dp, CONST char *dirname)
 	info.namelen = strlen (info.devname);
 	service_name (&info);
     }
+    closedir (dp);
 }   /*  End Function do_scan_and_service  */
 
 static flag make_symlink (const char *oldpath, const char *newpath)
